# coding: utf-8

"""
    rds_mysql_v2

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ParameterChangeLogForDescribeDBInstanceParametersLogOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'modify_time': 'str',
        'new_parameter_value': 'str',
        'old_parameter_value': 'str',
        'parameter_name': 'str',
        'status': 'str'
    }

    attribute_map = {
        'modify_time': 'ModifyTime',
        'new_parameter_value': 'NewParameterValue',
        'old_parameter_value': 'OldParameterValue',
        'parameter_name': 'ParameterName',
        'status': 'Status'
    }

    def __init__(self, modify_time=None, new_parameter_value=None, old_parameter_value=None, parameter_name=None, status=None, _configuration=None):  # noqa: E501
        """ParameterChangeLogForDescribeDBInstanceParametersLogOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._modify_time = None
        self._new_parameter_value = None
        self._old_parameter_value = None
        self._parameter_name = None
        self._status = None
        self.discriminator = None

        if modify_time is not None:
            self.modify_time = modify_time
        if new_parameter_value is not None:
            self.new_parameter_value = new_parameter_value
        if old_parameter_value is not None:
            self.old_parameter_value = old_parameter_value
        if parameter_name is not None:
            self.parameter_name = parameter_name
        if status is not None:
            self.status = status

    @property
    def modify_time(self):
        """Gets the modify_time of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.  # noqa: E501


        :return: The modify_time of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.  # noqa: E501
        :rtype: str
        """
        return self._modify_time

    @modify_time.setter
    def modify_time(self, modify_time):
        """Sets the modify_time of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.


        :param modify_time: The modify_time of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.  # noqa: E501
        :type: str
        """

        self._modify_time = modify_time

    @property
    def new_parameter_value(self):
        """Gets the new_parameter_value of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.  # noqa: E501


        :return: The new_parameter_value of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.  # noqa: E501
        :rtype: str
        """
        return self._new_parameter_value

    @new_parameter_value.setter
    def new_parameter_value(self, new_parameter_value):
        """Sets the new_parameter_value of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.


        :param new_parameter_value: The new_parameter_value of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.  # noqa: E501
        :type: str
        """

        self._new_parameter_value = new_parameter_value

    @property
    def old_parameter_value(self):
        """Gets the old_parameter_value of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.  # noqa: E501


        :return: The old_parameter_value of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.  # noqa: E501
        :rtype: str
        """
        return self._old_parameter_value

    @old_parameter_value.setter
    def old_parameter_value(self, old_parameter_value):
        """Sets the old_parameter_value of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.


        :param old_parameter_value: The old_parameter_value of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.  # noqa: E501
        :type: str
        """

        self._old_parameter_value = old_parameter_value

    @property
    def parameter_name(self):
        """Gets the parameter_name of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.  # noqa: E501


        :return: The parameter_name of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.  # noqa: E501
        :rtype: str
        """
        return self._parameter_name

    @parameter_name.setter
    def parameter_name(self, parameter_name):
        """Sets the parameter_name of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.


        :param parameter_name: The parameter_name of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.  # noqa: E501
        :type: str
        """

        self._parameter_name = parameter_name

    @property
    def status(self):
        """Gets the status of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.  # noqa: E501


        :return: The status of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.


        :param status: The status of this ParameterChangeLogForDescribeDBInstanceParametersLogOutput.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ParameterChangeLogForDescribeDBInstanceParametersLogOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ParameterChangeLogForDescribeDBInstanceParametersLogOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ParameterChangeLogForDescribeDBInstanceParametersLogOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vpn

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class CreateVpnGatewayRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bandwidth': 'int',
        'billing_type': 'int',
        'description': 'str',
        'period': 'int',
        'period_unit': 'str',
        'project_name': 'str',
        'subnet_id': 'str',
        'tags': 'list[TagForCreateVpnGatewayInput]',
        'vpc_id': 'str',
        'vpn_gateway_name': 'str'
    }

    attribute_map = {
        'bandwidth': 'Bandwidth',
        'billing_type': 'BillingType',
        'description': 'Description',
        'period': 'Period',
        'period_unit': 'PeriodUnit',
        'project_name': 'ProjectName',
        'subnet_id': 'SubnetId',
        'tags': 'Tags',
        'vpc_id': 'VpcId',
        'vpn_gateway_name': 'VpnGatewayName'
    }

    def __init__(self, bandwidth=None, billing_type=None, description=None, period=None, period_unit=None, project_name=None, subnet_id=None, tags=None, vpc_id=None, vpn_gateway_name=None, _configuration=None):  # noqa: E501
        """CreateVpnGatewayRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._bandwidth = None
        self._billing_type = None
        self._description = None
        self._period = None
        self._period_unit = None
        self._project_name = None
        self._subnet_id = None
        self._tags = None
        self._vpc_id = None
        self._vpn_gateway_name = None
        self.discriminator = None

        self.bandwidth = bandwidth
        if billing_type is not None:
            self.billing_type = billing_type
        if description is not None:
            self.description = description
        if period is not None:
            self.period = period
        if period_unit is not None:
            self.period_unit = period_unit
        if project_name is not None:
            self.project_name = project_name
        self.subnet_id = subnet_id
        if tags is not None:
            self.tags = tags
        self.vpc_id = vpc_id
        if vpn_gateway_name is not None:
            self.vpn_gateway_name = vpn_gateway_name

    @property
    def bandwidth(self):
        """Gets the bandwidth of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The bandwidth of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: int
        """
        return self._bandwidth

    @bandwidth.setter
    def bandwidth(self, bandwidth):
        """Sets the bandwidth of this CreateVpnGatewayRequest.


        :param bandwidth: The bandwidth of this CreateVpnGatewayRequest.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and bandwidth is None:
            raise ValueError("Invalid value for `bandwidth`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                bandwidth is not None and bandwidth > 1000):  # noqa: E501
            raise ValueError("Invalid value for `bandwidth`, must be a value less than or equal to `1000`")  # noqa: E501
        if (self._configuration.client_side_validation and
                bandwidth is not None and bandwidth < 5):  # noqa: E501
            raise ValueError("Invalid value for `bandwidth`, must be a value greater than or equal to `5`")  # noqa: E501

        self._bandwidth = bandwidth

    @property
    def billing_type(self):
        """Gets the billing_type of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The billing_type of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: int
        """
        return self._billing_type

    @billing_type.setter
    def billing_type(self, billing_type):
        """Sets the billing_type of this CreateVpnGatewayRequest.


        :param billing_type: The billing_type of this CreateVpnGatewayRequest.  # noqa: E501
        :type: int
        """
        if (self._configuration.client_side_validation and
                billing_type is not None and billing_type > 1):  # noqa: E501
            raise ValueError("Invalid value for `billing_type`, must be a value less than or equal to `1`")  # noqa: E501
        if (self._configuration.client_side_validation and
                billing_type is not None and billing_type < 1):  # noqa: E501
            raise ValueError("Invalid value for `billing_type`, must be a value greater than or equal to `1`")  # noqa: E501

        self._billing_type = billing_type

    @property
    def description(self):
        """Gets the description of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The description of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateVpnGatewayRequest.


        :param description: The description of this CreateVpnGatewayRequest.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                description is not None and len(description) > 255):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `255`")  # noqa: E501
        if (self._configuration.client_side_validation and
                description is not None and len(description) < 1):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `1`")  # noqa: E501

        self._description = description

    @property
    def period(self):
        """Gets the period of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The period of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this CreateVpnGatewayRequest.


        :param period: The period of this CreateVpnGatewayRequest.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def period_unit(self):
        """Gets the period_unit of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The period_unit of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: str
        """
        return self._period_unit

    @period_unit.setter
    def period_unit(self, period_unit):
        """Sets the period_unit of this CreateVpnGatewayRequest.


        :param period_unit: The period_unit of this CreateVpnGatewayRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["Month", "Year"]  # noqa: E501
        if (self._configuration.client_side_validation and
                period_unit not in allowed_values):
            raise ValueError(
                "Invalid value for `period_unit` ({0}), must be one of {1}"  # noqa: E501
                .format(period_unit, allowed_values)
            )

        self._period_unit = period_unit

    @property
    def project_name(self):
        """Gets the project_name of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The project_name of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this CreateVpnGatewayRequest.


        :param project_name: The project_name of this CreateVpnGatewayRequest.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def subnet_id(self):
        """Gets the subnet_id of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The subnet_id of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """Sets the subnet_id of this CreateVpnGatewayRequest.


        :param subnet_id: The subnet_id of this CreateVpnGatewayRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and subnet_id is None:
            raise ValueError("Invalid value for `subnet_id`, must not be `None`")  # noqa: E501

        self._subnet_id = subnet_id

    @property
    def tags(self):
        """Gets the tags of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The tags of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: list[TagForCreateVpnGatewayInput]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this CreateVpnGatewayRequest.


        :param tags: The tags of this CreateVpnGatewayRequest.  # noqa: E501
        :type: list[TagForCreateVpnGatewayInput]
        """

        self._tags = tags

    @property
    def vpc_id(self):
        """Gets the vpc_id of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The vpc_id of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this CreateVpnGatewayRequest.


        :param vpc_id: The vpc_id of this CreateVpnGatewayRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and vpc_id is None:
            raise ValueError("Invalid value for `vpc_id`, must not be `None`")  # noqa: E501

        self._vpc_id = vpc_id

    @property
    def vpn_gateway_name(self):
        """Gets the vpn_gateway_name of this CreateVpnGatewayRequest.  # noqa: E501


        :return: The vpn_gateway_name of this CreateVpnGatewayRequest.  # noqa: E501
        :rtype: str
        """
        return self._vpn_gateway_name

    @vpn_gateway_name.setter
    def vpn_gateway_name(self, vpn_gateway_name):
        """Sets the vpn_gateway_name of this CreateVpnGatewayRequest.


        :param vpn_gateway_name: The vpn_gateway_name of this CreateVpnGatewayRequest.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                vpn_gateway_name is not None and len(vpn_gateway_name) > 128):
            raise ValueError("Invalid value for `vpn_gateway_name`, length must be less than or equal to `128`")  # noqa: E501
        if (self._configuration.client_side_validation and
                vpn_gateway_name is not None and len(vpn_gateway_name) < 1):
            raise ValueError("Invalid value for `vpn_gateway_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._vpn_gateway_name = vpn_gateway_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateVpnGatewayRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateVpnGatewayRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateVpnGatewayRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    cen

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class CenBandwidthPackageForDescribeCenBandwidthPackagesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'bandwidth': 'int',
        'billing_type': 'int',
        'cen_bandwidth_package_id': 'str',
        'cen_bandwidth_package_name': 'str',
        'cen_ids': 'list[str]',
        'creation_time': 'str',
        'deleted_time': 'str',
        'description': 'str',
        'expired_time': 'str',
        'local_geographic_region_set_id': 'str',
        'peer_geographic_region_set_id': 'str',
        'project_name': 'str',
        'remaining_bandwidth': 'int',
        'status': 'str',
        'tags': 'list[TagForDescribeCenBandwidthPackagesOutput]'
    }

    attribute_map = {
        'account_id': 'AccountId',
        'bandwidth': 'Bandwidth',
        'billing_type': 'BillingType',
        'cen_bandwidth_package_id': 'CenBandwidthPackageId',
        'cen_bandwidth_package_name': 'CenBandwidthPackageName',
        'cen_ids': 'CenIds',
        'creation_time': 'CreationTime',
        'deleted_time': 'DeletedTime',
        'description': 'Description',
        'expired_time': 'ExpiredTime',
        'local_geographic_region_set_id': 'LocalGeographicRegionSetId',
        'peer_geographic_region_set_id': 'PeerGeographicRegionSetId',
        'project_name': 'ProjectName',
        'remaining_bandwidth': 'RemainingBandwidth',
        'status': 'Status',
        'tags': 'Tags'
    }

    def __init__(self, account_id=None, bandwidth=None, billing_type=None, cen_bandwidth_package_id=None, cen_bandwidth_package_name=None, cen_ids=None, creation_time=None, deleted_time=None, description=None, expired_time=None, local_geographic_region_set_id=None, peer_geographic_region_set_id=None, project_name=None, remaining_bandwidth=None, status=None, tags=None, _configuration=None):  # noqa: E501
        """CenBandwidthPackageForDescribeCenBandwidthPackagesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._account_id = None
        self._bandwidth = None
        self._billing_type = None
        self._cen_bandwidth_package_id = None
        self._cen_bandwidth_package_name = None
        self._cen_ids = None
        self._creation_time = None
        self._deleted_time = None
        self._description = None
        self._expired_time = None
        self._local_geographic_region_set_id = None
        self._peer_geographic_region_set_id = None
        self._project_name = None
        self._remaining_bandwidth = None
        self._status = None
        self._tags = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if bandwidth is not None:
            self.bandwidth = bandwidth
        if billing_type is not None:
            self.billing_type = billing_type
        if cen_bandwidth_package_id is not None:
            self.cen_bandwidth_package_id = cen_bandwidth_package_id
        if cen_bandwidth_package_name is not None:
            self.cen_bandwidth_package_name = cen_bandwidth_package_name
        if cen_ids is not None:
            self.cen_ids = cen_ids
        if creation_time is not None:
            self.creation_time = creation_time
        if deleted_time is not None:
            self.deleted_time = deleted_time
        if description is not None:
            self.description = description
        if expired_time is not None:
            self.expired_time = expired_time
        if local_geographic_region_set_id is not None:
            self.local_geographic_region_set_id = local_geographic_region_set_id
        if peer_geographic_region_set_id is not None:
            self.peer_geographic_region_set_id = peer_geographic_region_set_id
        if project_name is not None:
            self.project_name = project_name
        if remaining_bandwidth is not None:
            self.remaining_bandwidth = remaining_bandwidth
        if status is not None:
            self.status = status
        if tags is not None:
            self.tags = tags

    @property
    def account_id(self):
        """Gets the account_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The account_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param account_id: The account_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def bandwidth(self):
        """Gets the bandwidth of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The bandwidth of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: int
        """
        return self._bandwidth

    @bandwidth.setter
    def bandwidth(self, bandwidth):
        """Sets the bandwidth of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param bandwidth: The bandwidth of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: int
        """

        self._bandwidth = bandwidth

    @property
    def billing_type(self):
        """Gets the billing_type of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The billing_type of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: int
        """
        return self._billing_type

    @billing_type.setter
    def billing_type(self, billing_type):
        """Sets the billing_type of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param billing_type: The billing_type of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: int
        """

        self._billing_type = billing_type

    @property
    def cen_bandwidth_package_id(self):
        """Gets the cen_bandwidth_package_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The cen_bandwidth_package_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._cen_bandwidth_package_id

    @cen_bandwidth_package_id.setter
    def cen_bandwidth_package_id(self, cen_bandwidth_package_id):
        """Sets the cen_bandwidth_package_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param cen_bandwidth_package_id: The cen_bandwidth_package_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: str
        """

        self._cen_bandwidth_package_id = cen_bandwidth_package_id

    @property
    def cen_bandwidth_package_name(self):
        """Gets the cen_bandwidth_package_name of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The cen_bandwidth_package_name of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._cen_bandwidth_package_name

    @cen_bandwidth_package_name.setter
    def cen_bandwidth_package_name(self, cen_bandwidth_package_name):
        """Sets the cen_bandwidth_package_name of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param cen_bandwidth_package_name: The cen_bandwidth_package_name of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: str
        """

        self._cen_bandwidth_package_name = cen_bandwidth_package_name

    @property
    def cen_ids(self):
        """Gets the cen_ids of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The cen_ids of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._cen_ids

    @cen_ids.setter
    def cen_ids(self, cen_ids):
        """Sets the cen_ids of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param cen_ids: The cen_ids of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: list[str]
        """

        self._cen_ids = cen_ids

    @property
    def creation_time(self):
        """Gets the creation_time of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The creation_time of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param creation_time: The creation_time of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: str
        """

        self._creation_time = creation_time

    @property
    def deleted_time(self):
        """Gets the deleted_time of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The deleted_time of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._deleted_time

    @deleted_time.setter
    def deleted_time(self, deleted_time):
        """Sets the deleted_time of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param deleted_time: The deleted_time of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: str
        """

        self._deleted_time = deleted_time

    @property
    def description(self):
        """Gets the description of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The description of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param description: The description of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def expired_time(self):
        """Gets the expired_time of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The expired_time of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._expired_time

    @expired_time.setter
    def expired_time(self, expired_time):
        """Sets the expired_time of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param expired_time: The expired_time of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: str
        """

        self._expired_time = expired_time

    @property
    def local_geographic_region_set_id(self):
        """Gets the local_geographic_region_set_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The local_geographic_region_set_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._local_geographic_region_set_id

    @local_geographic_region_set_id.setter
    def local_geographic_region_set_id(self, local_geographic_region_set_id):
        """Sets the local_geographic_region_set_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param local_geographic_region_set_id: The local_geographic_region_set_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: str
        """

        self._local_geographic_region_set_id = local_geographic_region_set_id

    @property
    def peer_geographic_region_set_id(self):
        """Gets the peer_geographic_region_set_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The peer_geographic_region_set_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._peer_geographic_region_set_id

    @peer_geographic_region_set_id.setter
    def peer_geographic_region_set_id(self, peer_geographic_region_set_id):
        """Sets the peer_geographic_region_set_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param peer_geographic_region_set_id: The peer_geographic_region_set_id of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: str
        """

        self._peer_geographic_region_set_id = peer_geographic_region_set_id

    @property
    def project_name(self):
        """Gets the project_name of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The project_name of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param project_name: The project_name of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def remaining_bandwidth(self):
        """Gets the remaining_bandwidth of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The remaining_bandwidth of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: int
        """
        return self._remaining_bandwidth

    @remaining_bandwidth.setter
    def remaining_bandwidth(self, remaining_bandwidth):
        """Sets the remaining_bandwidth of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param remaining_bandwidth: The remaining_bandwidth of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: int
        """

        self._remaining_bandwidth = remaining_bandwidth

    @property
    def status(self):
        """Gets the status of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The status of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param status: The status of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def tags(self):
        """Gets the tags of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501


        :return: The tags of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :rtype: list[TagForDescribeCenBandwidthPackagesOutput]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.


        :param tags: The tags of this CenBandwidthPackageForDescribeCenBandwidthPackagesOutput.  # noqa: E501
        :type: list[TagForDescribeCenBandwidthPackagesOutput]
        """

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CenBandwidthPackageForDescribeCenBandwidthPackagesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CenBandwidthPackageForDescribeCenBandwidthPackagesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CenBandwidthPackageForDescribeCenBandwidthPackagesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    clb

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from volcenginesdkclb.models.access_log_for_describe_load_balancer_attributes_output import AccessLogForDescribeLoadBalancerAttributesOutput
from volcenginesdkclb.models.acl_entry_for_add_acl_entries_input import AclEntryForAddAclEntriesInput
from volcenginesdkclb.models.acl_entry_for_describe_acl_attributes_output import AclEntryForDescribeAclAttributesOutput
from volcenginesdkclb.models.acl_for_describe_acls_output import AclForDescribeAclsOutput
from volcenginesdkclb.models.add_acl_entries_request import AddAclEntriesRequest
from volcenginesdkclb.models.add_acl_entries_response import AddAclEntriesResponse
from volcenginesdkclb.models.add_server_group_backend_servers_request import AddServerGroupBackendServersRequest
from volcenginesdkclb.models.add_server_group_backend_servers_response import AddServerGroupBackendServersResponse
from volcenginesdkclb.models.attach_health_check_log_topic_request import AttachHealthCheckLogTopicRequest
from volcenginesdkclb.models.attach_health_check_log_topic_response import AttachHealthCheckLogTopicResponse
from volcenginesdkclb.models.certificate_for_describe_certificates_output import CertificateForDescribeCertificatesOutput
from volcenginesdkclb.models.convert_load_balancer_billing_type_request import ConvertLoadBalancerBillingTypeRequest
from volcenginesdkclb.models.convert_load_balancer_billing_type_response import ConvertLoadBalancerBillingTypeResponse
from volcenginesdkclb.models.create_acl_request import CreateAclRequest
from volcenginesdkclb.models.create_acl_response import CreateAclResponse
from volcenginesdkclb.models.create_health_check_log_project_request import CreateHealthCheckLogProjectRequest
from volcenginesdkclb.models.create_health_check_log_project_response import CreateHealthCheckLogProjectResponse
from volcenginesdkclb.models.create_listener_request import CreateListenerRequest
from volcenginesdkclb.models.create_listener_response import CreateListenerResponse
from volcenginesdkclb.models.create_load_balancer_request import CreateLoadBalancerRequest
from volcenginesdkclb.models.create_load_balancer_response import CreateLoadBalancerResponse
from volcenginesdkclb.models.create_rules_request import CreateRulesRequest
from volcenginesdkclb.models.create_rules_response import CreateRulesResponse
from volcenginesdkclb.models.create_server_group_request import CreateServerGroupRequest
from volcenginesdkclb.models.create_server_group_response import CreateServerGroupResponse
from volcenginesdkclb.models.delete_acl_request import DeleteAclRequest
from volcenginesdkclb.models.delete_acl_response import DeleteAclResponse
from volcenginesdkclb.models.delete_certificate_request import DeleteCertificateRequest
from volcenginesdkclb.models.delete_certificate_response import DeleteCertificateResponse
from volcenginesdkclb.models.delete_health_check_log_project_request import DeleteHealthCheckLogProjectRequest
from volcenginesdkclb.models.delete_health_check_log_project_response import DeleteHealthCheckLogProjectResponse
from volcenginesdkclb.models.delete_listener_request import DeleteListenerRequest
from volcenginesdkclb.models.delete_listener_response import DeleteListenerResponse
from volcenginesdkclb.models.delete_load_balancer_request import DeleteLoadBalancerRequest
from volcenginesdkclb.models.delete_load_balancer_response import DeleteLoadBalancerResponse
from volcenginesdkclb.models.delete_rules_request import DeleteRulesRequest
from volcenginesdkclb.models.delete_rules_response import DeleteRulesResponse
from volcenginesdkclb.models.delete_server_group_request import DeleteServerGroupRequest
from volcenginesdkclb.models.delete_server_group_response import DeleteServerGroupResponse
from volcenginesdkclb.models.describe_acl_attributes_request import DescribeAclAttributesRequest
from volcenginesdkclb.models.describe_acl_attributes_response import DescribeAclAttributesResponse
from volcenginesdkclb.models.describe_acls_request import DescribeAclsRequest
from volcenginesdkclb.models.describe_acls_response import DescribeAclsResponse
from volcenginesdkclb.models.describe_certificates_request import DescribeCertificatesRequest
from volcenginesdkclb.models.describe_certificates_response import DescribeCertificatesResponse
from volcenginesdkclb.models.describe_health_check_log_project_attributes_request import DescribeHealthCheckLogProjectAttributesRequest
from volcenginesdkclb.models.describe_health_check_log_project_attributes_response import DescribeHealthCheckLogProjectAttributesResponse
from volcenginesdkclb.models.describe_health_check_log_topic_attributes_request import DescribeHealthCheckLogTopicAttributesRequest
from volcenginesdkclb.models.describe_health_check_log_topic_attributes_response import DescribeHealthCheckLogTopicAttributesResponse
from volcenginesdkclb.models.describe_listener_attributes_request import DescribeListenerAttributesRequest
from volcenginesdkclb.models.describe_listener_attributes_response import DescribeListenerAttributesResponse
from volcenginesdkclb.models.describe_listener_health_request import DescribeListenerHealthRequest
from volcenginesdkclb.models.describe_listener_health_response import DescribeListenerHealthResponse
from volcenginesdkclb.models.describe_listeners_request import DescribeListenersRequest
from volcenginesdkclb.models.describe_listeners_response import DescribeListenersResponse
from volcenginesdkclb.models.describe_load_balancer_attributes_request import DescribeLoadBalancerAttributesRequest
from volcenginesdkclb.models.describe_load_balancer_attributes_response import DescribeLoadBalancerAttributesResponse
from volcenginesdkclb.models.describe_load_balancers_billing_request import DescribeLoadBalancersBillingRequest
from volcenginesdkclb.models.describe_load_balancers_billing_response import DescribeLoadBalancersBillingResponse
from volcenginesdkclb.models.describe_load_balancers_request import DescribeLoadBalancersRequest
from volcenginesdkclb.models.describe_load_balancers_response import DescribeLoadBalancersResponse
from volcenginesdkclb.models.describe_rules_request import DescribeRulesRequest
from volcenginesdkclb.models.describe_rules_response import DescribeRulesResponse
from volcenginesdkclb.models.describe_server_group_attributes_request import DescribeServerGroupAttributesRequest
from volcenginesdkclb.models.describe_server_group_attributes_response import DescribeServerGroupAttributesResponse
from volcenginesdkclb.models.describe_server_groups_request import DescribeServerGroupsRequest
from volcenginesdkclb.models.describe_server_groups_response import DescribeServerGroupsResponse
from volcenginesdkclb.models.describe_zones_request import DescribeZonesRequest
from volcenginesdkclb.models.describe_zones_response import DescribeZonesResponse
from volcenginesdkclb.models.detach_health_check_log_topic_request import DetachHealthCheckLogTopicRequest
from volcenginesdkclb.models.detach_health_check_log_topic_response import DetachHealthCheckLogTopicResponse
from volcenginesdkclb.models.disable_access_log_request import DisableAccessLogRequest
from volcenginesdkclb.models.disable_access_log_response import DisableAccessLogResponse
from volcenginesdkclb.models.eip_billing_config_for_create_load_balancer_input import EipBillingConfigForCreateLoadBalancerInput
from volcenginesdkclb.models.eip_for_describe_load_balancer_attributes_output import EipForDescribeLoadBalancerAttributesOutput
from volcenginesdkclb.models.enable_access_log_request import EnableAccessLogRequest
from volcenginesdkclb.models.enable_access_log_response import EnableAccessLogResponse
from volcenginesdkclb.models.health_check_for_create_listener_input import HealthCheckForCreateListenerInput
from volcenginesdkclb.models.health_check_for_describe_listener_attributes_output import HealthCheckForDescribeListenerAttributesOutput
from volcenginesdkclb.models.health_check_for_describe_listeners_output import HealthCheckForDescribeListenersOutput
from volcenginesdkclb.models.health_check_for_modify_listener_attributes_input import HealthCheckForModifyListenerAttributesInput
from volcenginesdkclb.models.list_tags_for_resources_request import ListTagsForResourcesRequest
from volcenginesdkclb.models.list_tags_for_resources_response import ListTagsForResourcesResponse
from volcenginesdkclb.models.listener_for_describe_acl_attributes_output import ListenerForDescribeAclAttributesOutput
from volcenginesdkclb.models.listener_for_describe_listeners_output import ListenerForDescribeListenersOutput
from volcenginesdkclb.models.listener_for_describe_load_balancer_attributes_output import ListenerForDescribeLoadBalancerAttributesOutput
from volcenginesdkclb.models.load_balancer_billing_config_for_describe_load_balancers_billing_output import LoadBalancerBillingConfigForDescribeLoadBalancersBillingOutput
from volcenginesdkclb.models.load_balancer_for_describe_load_balancers_output import LoadBalancerForDescribeLoadBalancersOutput
from volcenginesdkclb.models.master_zone_for_describe_zones_output import MasterZoneForDescribeZonesOutput
from volcenginesdkclb.models.modify_acl_attributes_request import ModifyAclAttributesRequest
from volcenginesdkclb.models.modify_acl_attributes_response import ModifyAclAttributesResponse
from volcenginesdkclb.models.modify_listener_attributes_request import ModifyListenerAttributesRequest
from volcenginesdkclb.models.modify_listener_attributes_response import ModifyListenerAttributesResponse
from volcenginesdkclb.models.modify_load_balancer_attributes_request import ModifyLoadBalancerAttributesRequest
from volcenginesdkclb.models.modify_load_balancer_attributes_response import ModifyLoadBalancerAttributesResponse
from volcenginesdkclb.models.modify_rules_request import ModifyRulesRequest
from volcenginesdkclb.models.modify_rules_response import ModifyRulesResponse
from volcenginesdkclb.models.modify_server_group_attributes_request import ModifyServerGroupAttributesRequest
from volcenginesdkclb.models.modify_server_group_attributes_response import ModifyServerGroupAttributesResponse
from volcenginesdkclb.models.remove_acl_entries_request import RemoveAclEntriesRequest
from volcenginesdkclb.models.remove_acl_entries_response import RemoveAclEntriesResponse
from volcenginesdkclb.models.remove_server_group_backend_servers_request import RemoveServerGroupBackendServersRequest
from volcenginesdkclb.models.remove_server_group_backend_servers_response import RemoveServerGroupBackendServersResponse
from volcenginesdkclb.models.renew_load_balancer_request import RenewLoadBalancerRequest
from volcenginesdkclb.models.renew_load_balancer_response import RenewLoadBalancerResponse
from volcenginesdkclb.models.resource_tag_for_list_tags_for_resources_output import ResourceTagForListTagsForResourcesOutput
from volcenginesdkclb.models.result_for_describe_listener_health_output import ResultForDescribeListenerHealthOutput
from volcenginesdkclb.models.rule_for_create_rules_input import RuleForCreateRulesInput
from volcenginesdkclb.models.rule_for_describe_rules_output import RuleForDescribeRulesOutput
from volcenginesdkclb.models.rule_for_modify_rules_input import RuleForModifyRulesInput
from volcenginesdkclb.models.server_for_add_server_group_backend_servers_input import ServerForAddServerGroupBackendServersInput
from volcenginesdkclb.models.server_for_create_server_group_input import ServerForCreateServerGroupInput
from volcenginesdkclb.models.server_for_describe_server_group_attributes_output import ServerForDescribeServerGroupAttributesOutput
from volcenginesdkclb.models.server_for_modify_server_group_attributes_input import ServerForModifyServerGroupAttributesInput
from volcenginesdkclb.models.server_group_for_describe_load_balancer_attributes_output import ServerGroupForDescribeLoadBalancerAttributesOutput
from volcenginesdkclb.models.server_group_for_describe_server_groups_output import ServerGroupForDescribeServerGroupsOutput
from volcenginesdkclb.models.set_load_balancer_renewal_request import SetLoadBalancerRenewalRequest
from volcenginesdkclb.models.set_load_balancer_renewal_response import SetLoadBalancerRenewalResponse
from volcenginesdkclb.models.tag_filter_for_describe_load_balancers_input import TagFilterForDescribeLoadBalancersInput
from volcenginesdkclb.models.tag_filter_for_list_tags_for_resources_input import TagFilterForListTagsForResourcesInput
from volcenginesdkclb.models.tag_for_create_load_balancer_input import TagForCreateLoadBalancerInput
from volcenginesdkclb.models.tag_for_describe_load_balancer_attributes_output import TagForDescribeLoadBalancerAttributesOutput
from volcenginesdkclb.models.tag_for_describe_load_balancers_output import TagForDescribeLoadBalancersOutput
from volcenginesdkclb.models.tag_for_tag_resources_input import TagForTagResourcesInput
from volcenginesdkclb.models.tag_resources_request import TagResourcesRequest
from volcenginesdkclb.models.tag_resources_response import TagResourcesResponse
from volcenginesdkclb.models.untag_resources_request import UntagResourcesRequest
from volcenginesdkclb.models.untag_resources_response import UntagResourcesResponse
from volcenginesdkclb.models.upload_certificate_request import UploadCertificateRequest
from volcenginesdkclb.models.upload_certificate_response import UploadCertificateResponse



# coding: utf-8

# flake8: noqa
"""
    rds_mysql_v2

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from volcenginesdkrdsmysqlv2.models.account_for_describe_db_accounts_output import AccountForDescribeDBAccountsOutput
from volcenginesdkrdsmysqlv2.models.account_privilege_for_create_db_account_input import AccountPrivilegeForCreateDBAccountInput
from volcenginesdkrdsmysqlv2.models.account_privilege_for_describe_db_accounts_output import AccountPrivilegeForDescribeDBAccountsOutput
from volcenginesdkrdsmysqlv2.models.account_privilege_for_grant_db_account_privilege_input import AccountPrivilegeForGrantDBAccountPrivilegeInput
from volcenginesdkrdsmysqlv2.models.address_for_describe_db_instance_detail_output import AddressForDescribeDBInstanceDetailOutput
from volcenginesdkrdsmysqlv2.models.address_object_for_describe_db_instances_output import AddressObjectForDescribeDBInstancesOutput
from volcenginesdkrdsmysqlv2.models.allow_list_for_describe_allow_lists_output import AllowListForDescribeAllowListsOutput
from volcenginesdkrdsmysqlv2.models.associate_allow_list_request import AssociateAllowListRequest
from volcenginesdkrdsmysqlv2.models.associate_allow_list_response import AssociateAllowListResponse
from volcenginesdkrdsmysqlv2.models.associated_instance_for_describe_allow_list_detail_output import AssociatedInstanceForDescribeAllowListDetailOutput
from volcenginesdkrdsmysqlv2.models.backup_for_describe_backups_output import BackupForDescribeBackupsOutput
from volcenginesdkrdsmysqlv2.models.backup_meta_for_create_backup_input import BackupMetaForCreateBackupInput
from volcenginesdkrdsmysqlv2.models.basic_info_for_describe_db_instance_detail_output import BasicInfoForDescribeDBInstanceDetailOutput
from volcenginesdkrdsmysqlv2.models.charge_detail_for_describe_db_instance_detail_output import ChargeDetailForDescribeDBInstanceDetailOutput
from volcenginesdkrdsmysqlv2.models.charge_detail_for_describe_db_instances_output import ChargeDetailForDescribeDBInstancesOutput
from volcenginesdkrdsmysqlv2.models.charge_info_for_create_db_instance_input import ChargeInfoForCreateDBInstanceInput
from volcenginesdkrdsmysqlv2.models.charge_info_for_restore_to_new_instance_input import ChargeInfoForRestoreToNewInstanceInput
from volcenginesdkrdsmysqlv2.models.create_allow_list_request import CreateAllowListRequest
from volcenginesdkrdsmysqlv2.models.create_allow_list_response import CreateAllowListResponse
from volcenginesdkrdsmysqlv2.models.create_backup_request import CreateBackupRequest
from volcenginesdkrdsmysqlv2.models.create_backup_response import CreateBackupResponse
from volcenginesdkrdsmysqlv2.models.create_db_account_request import CreateDBAccountRequest
from volcenginesdkrdsmysqlv2.models.create_db_account_response import CreateDBAccountResponse
from volcenginesdkrdsmysqlv2.models.create_db_endpoint_public_address_request import CreateDBEndpointPublicAddressRequest
from volcenginesdkrdsmysqlv2.models.create_db_endpoint_public_address_response import CreateDBEndpointPublicAddressResponse
from volcenginesdkrdsmysqlv2.models.create_db_endpoint_request import CreateDBEndpointRequest
from volcenginesdkrdsmysqlv2.models.create_db_endpoint_response import CreateDBEndpointResponse
from volcenginesdkrdsmysqlv2.models.create_db_instance_request import CreateDBInstanceRequest
from volcenginesdkrdsmysqlv2.models.create_db_instance_response import CreateDBInstanceResponse
from volcenginesdkrdsmysqlv2.models.create_database_request import CreateDatabaseRequest
from volcenginesdkrdsmysqlv2.models.create_database_response import CreateDatabaseResponse
from volcenginesdkrdsmysqlv2.models.db_table_info_for_describe_backups_output import DBTableInfoForDescribeBackupsOutput
from volcenginesdkrdsmysqlv2.models.databas_for_describe_databases_output import DatabasForDescribeDatabasesOutput
from volcenginesdkrdsmysqlv2.models.database_privilege_for_create_database_input import DatabasePrivilegeForCreateDatabaseInput
from volcenginesdkrdsmysqlv2.models.database_privilege_for_describe_databases_output import DatabasePrivilegeForDescribeDatabasesOutput
from volcenginesdkrdsmysqlv2.models.database_privilege_for_grant_database_privilege_input import DatabasePrivilegeForGrantDatabasePrivilegeInput
from volcenginesdkrdsmysqlv2.models.delete_allow_list_request import DeleteAllowListRequest
from volcenginesdkrdsmysqlv2.models.delete_allow_list_response import DeleteAllowListResponse
from volcenginesdkrdsmysqlv2.models.delete_db_account_request import DeleteDBAccountRequest
from volcenginesdkrdsmysqlv2.models.delete_db_account_response import DeleteDBAccountResponse
from volcenginesdkrdsmysqlv2.models.delete_db_endpoint_public_address_request import DeleteDBEndpointPublicAddressRequest
from volcenginesdkrdsmysqlv2.models.delete_db_endpoint_public_address_response import DeleteDBEndpointPublicAddressResponse
from volcenginesdkrdsmysqlv2.models.delete_db_endpoint_request import DeleteDBEndpointRequest
from volcenginesdkrdsmysqlv2.models.delete_db_endpoint_response import DeleteDBEndpointResponse
from volcenginesdkrdsmysqlv2.models.delete_db_instance_request import DeleteDBInstanceRequest
from volcenginesdkrdsmysqlv2.models.delete_db_instance_response import DeleteDBInstanceResponse
from volcenginesdkrdsmysqlv2.models.delete_database_request import DeleteDatabaseRequest
from volcenginesdkrdsmysqlv2.models.delete_database_response import DeleteDatabaseResponse
from volcenginesdkrdsmysqlv2.models.describe_allow_list_detail_request import DescribeAllowListDetailRequest
from volcenginesdkrdsmysqlv2.models.describe_allow_list_detail_response import DescribeAllowListDetailResponse
from volcenginesdkrdsmysqlv2.models.describe_allow_lists_request import DescribeAllowListsRequest
from volcenginesdkrdsmysqlv2.models.describe_allow_lists_response import DescribeAllowListsResponse
from volcenginesdkrdsmysqlv2.models.describe_availability_zones_request import DescribeAvailabilityZonesRequest
from volcenginesdkrdsmysqlv2.models.describe_availability_zones_response import DescribeAvailabilityZonesResponse
from volcenginesdkrdsmysqlv2.models.describe_backups_request import DescribeBackupsRequest
from volcenginesdkrdsmysqlv2.models.describe_backups_response import DescribeBackupsResponse
from volcenginesdkrdsmysqlv2.models.describe_db_accounts_request import DescribeDBAccountsRequest
from volcenginesdkrdsmysqlv2.models.describe_db_accounts_response import DescribeDBAccountsResponse
from volcenginesdkrdsmysqlv2.models.describe_db_instance_detail_request import DescribeDBInstanceDetailRequest
from volcenginesdkrdsmysqlv2.models.describe_db_instance_detail_response import DescribeDBInstanceDetailResponse
from volcenginesdkrdsmysqlv2.models.describe_db_instance_parameters_log_request import DescribeDBInstanceParametersLogRequest
from volcenginesdkrdsmysqlv2.models.describe_db_instance_parameters_log_response import DescribeDBInstanceParametersLogResponse
from volcenginesdkrdsmysqlv2.models.describe_db_instance_parameters_request import DescribeDBInstanceParametersRequest
from volcenginesdkrdsmysqlv2.models.describe_db_instance_parameters_response import DescribeDBInstanceParametersResponse
from volcenginesdkrdsmysqlv2.models.describe_db_instances_request import DescribeDBInstancesRequest
from volcenginesdkrdsmysqlv2.models.describe_db_instances_response import DescribeDBInstancesResponse
from volcenginesdkrdsmysqlv2.models.describe_databases_request import DescribeDatabasesRequest
from volcenginesdkrdsmysqlv2.models.describe_databases_response import DescribeDatabasesResponse
from volcenginesdkrdsmysqlv2.models.describe_recoverable_time_request import DescribeRecoverableTimeRequest
from volcenginesdkrdsmysqlv2.models.describe_recoverable_time_response import DescribeRecoverableTimeResponse
from volcenginesdkrdsmysqlv2.models.describe_regions_request import DescribeRegionsRequest
from volcenginesdkrdsmysqlv2.models.describe_regions_response import DescribeRegionsResponse
from volcenginesdkrdsmysqlv2.models.disassociate_allow_list_request import DisassociateAllowListRequest
from volcenginesdkrdsmysqlv2.models.disassociate_allow_list_response import DisassociateAllowListResponse
from volcenginesdkrdsmysqlv2.models.download_backup_request import DownloadBackupRequest
from volcenginesdkrdsmysqlv2.models.download_backup_response import DownloadBackupResponse
from volcenginesdkrdsmysqlv2.models.endpoint_for_describe_db_instance_detail_output import EndpointForDescribeDBInstanceDetailOutput
from volcenginesdkrdsmysqlv2.models.get_backup_download_link_request import GetBackupDownloadLinkRequest
from volcenginesdkrdsmysqlv2.models.get_backup_download_link_response import GetBackupDownloadLinkResponse
from volcenginesdkrdsmysqlv2.models.grant_db_account_privilege_request import GrantDBAccountPrivilegeRequest
from volcenginesdkrdsmysqlv2.models.grant_db_account_privilege_response import GrantDBAccountPrivilegeResponse
from volcenginesdkrdsmysqlv2.models.grant_database_privilege_request import GrantDatabasePrivilegeRequest
from volcenginesdkrdsmysqlv2.models.grant_database_privilege_response import GrantDatabasePrivilegeResponse
from volcenginesdkrdsmysqlv2.models.instance_for_describe_db_instances_output import InstanceForDescribeDBInstancesOutput
from volcenginesdkrdsmysqlv2.models.instance_tag_for_create_db_instance_input import InstanceTagForCreateDBInstanceInput
from volcenginesdkrdsmysqlv2.models.maintenance_window_for_describe_db_instance_detail_output import MaintenanceWindowForDescribeDBInstanceDetailOutput
from volcenginesdkrdsmysqlv2.models.maintenance_window_for_describe_db_instances_output import MaintenanceWindowForDescribeDBInstancesOutput
from volcenginesdkrdsmysqlv2.models.modify_allow_list_request import ModifyAllowListRequest
from volcenginesdkrdsmysqlv2.models.modify_allow_list_response import ModifyAllowListResponse
from volcenginesdkrdsmysqlv2.models.modify_db_endpoint_address_request import ModifyDBEndpointAddressRequest
from volcenginesdkrdsmysqlv2.models.modify_db_endpoint_address_response import ModifyDBEndpointAddressResponse
from volcenginesdkrdsmysqlv2.models.modify_db_endpoint_dns_request import ModifyDBEndpointDNSRequest
from volcenginesdkrdsmysqlv2.models.modify_db_endpoint_dns_response import ModifyDBEndpointDNSResponse
from volcenginesdkrdsmysqlv2.models.modify_db_endpoint_request import ModifyDBEndpointRequest
from volcenginesdkrdsmysqlv2.models.modify_db_endpoint_response import ModifyDBEndpointResponse
from volcenginesdkrdsmysqlv2.models.modify_db_instance_parameters_request import ModifyDBInstanceParametersRequest
from volcenginesdkrdsmysqlv2.models.modify_db_instance_parameters_response import ModifyDBInstanceParametersResponse
from volcenginesdkrdsmysqlv2.models.modify_db_instance_spec_request import ModifyDBInstanceSpecRequest
from volcenginesdkrdsmysqlv2.models.modify_db_instance_spec_response import ModifyDBInstanceSpecResponse
from volcenginesdkrdsmysqlv2.models.node_for_describe_db_instance_detail_output import NodeForDescribeDBInstanceDetailOutput
from volcenginesdkrdsmysqlv2.models.node_info_for_create_db_instance_input import NodeInfoForCreateDBInstanceInput
from volcenginesdkrdsmysqlv2.models.node_info_for_modify_db_instance_spec_input import NodeInfoForModifyDBInstanceSpecInput
from volcenginesdkrdsmysqlv2.models.node_info_for_restore_to_new_instance_input import NodeInfoForRestoreToNewInstanceInput
from volcenginesdkrdsmysqlv2.models.parameter_change_log_for_describe_db_instance_parameters_log_output import ParameterChangeLogForDescribeDBInstanceParametersLogOutput
from volcenginesdkrdsmysqlv2.models.parameter_for_describe_db_instance_parameters_output import ParameterForDescribeDBInstanceParametersOutput
from volcenginesdkrdsmysqlv2.models.parameter_for_modify_db_instance_parameters_input import ParameterForModifyDBInstanceParametersInput
from volcenginesdkrdsmysqlv2.models.read_only_node_weight_for_describe_db_instance_detail_output import ReadOnlyNodeWeightForDescribeDBInstanceDetailOutput
from volcenginesdkrdsmysqlv2.models.read_only_node_weight_for_modify_db_endpoint_input import ReadOnlyNodeWeightForModifyDBEndpointInput
from volcenginesdkrdsmysqlv2.models.recoverable_time_info_for_describe_recoverable_time_output import RecoverableTimeInfoForDescribeRecoverableTimeOutput
from volcenginesdkrdsmysqlv2.models.region_for_describe_regions_output import RegionForDescribeRegionsOutput
from volcenginesdkrdsmysqlv2.models.reset_db_account_request import ResetDBAccountRequest
from volcenginesdkrdsmysqlv2.models.reset_db_account_response import ResetDBAccountResponse
from volcenginesdkrdsmysqlv2.models.restart_db_instance_request import RestartDBInstanceRequest
from volcenginesdkrdsmysqlv2.models.restart_db_instance_response import RestartDBInstanceResponse
from volcenginesdkrdsmysqlv2.models.restore_to_new_instance_request import RestoreToNewInstanceRequest
from volcenginesdkrdsmysqlv2.models.restore_to_new_instance_response import RestoreToNewInstanceResponse
from volcenginesdkrdsmysqlv2.models.revoke_db_account_privilege_request import RevokeDBAccountPrivilegeRequest
from volcenginesdkrdsmysqlv2.models.revoke_db_account_privilege_response import RevokeDBAccountPrivilegeResponse
from volcenginesdkrdsmysqlv2.models.revoke_database_privilege_request import RevokeDatabasePrivilegeRequest
from volcenginesdkrdsmysqlv2.models.revoke_database_privilege_response import RevokeDatabasePrivilegeResponse
from volcenginesdkrdsmysqlv2.models.tag_for_describe_db_instance_detail_output import TagForDescribeDBInstanceDetailOutput
from volcenginesdkrdsmysqlv2.models.upgrade_allow_list_version_request import UpgradeAllowListVersionRequest
from volcenginesdkrdsmysqlv2.models.upgrade_allow_list_version_response import UpgradeAllowListVersionResponse
from volcenginesdkrdsmysqlv2.models.zone_for_describe_availability_zones_output import ZoneForDescribeAvailabilityZonesOutput



# coding: utf-8

"""
    ecs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeAvailableResourceRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'destination_resource': 'str',
        'instance_charge_type': 'str',
        'instance_type': 'str',
        'instance_type_id': 'str',
        'spot_strategy': 'str',
        'zone_id': 'str'
    }

    attribute_map = {
        'destination_resource': 'DestinationResource',
        'instance_charge_type': 'InstanceChargeType',
        'instance_type': 'InstanceType',
        'instance_type_id': 'InstanceTypeId',
        'spot_strategy': 'SpotStrategy',
        'zone_id': 'ZoneId'
    }

    def __init__(self, destination_resource=None, instance_charge_type=None, instance_type=None, instance_type_id=None, spot_strategy=None, zone_id=None, _configuration=None):  # noqa: E501
        """DescribeAvailableResourceRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._destination_resource = None
        self._instance_charge_type = None
        self._instance_type = None
        self._instance_type_id = None
        self._spot_strategy = None
        self._zone_id = None
        self.discriminator = None

        if destination_resource is not None:
            self.destination_resource = destination_resource
        if instance_charge_type is not None:
            self.instance_charge_type = instance_charge_type
        if instance_type is not None:
            self.instance_type = instance_type
        if instance_type_id is not None:
            self.instance_type_id = instance_type_id
        if spot_strategy is not None:
            self.spot_strategy = spot_strategy
        if zone_id is not None:
            self.zone_id = zone_id

    @property
    def destination_resource(self):
        """Gets the destination_resource of this DescribeAvailableResourceRequest.  # noqa: E501


        :return: The destination_resource of this DescribeAvailableResourceRequest.  # noqa: E501
        :rtype: str
        """
        return self._destination_resource

    @destination_resource.setter
    def destination_resource(self, destination_resource):
        """Sets the destination_resource of this DescribeAvailableResourceRequest.


        :param destination_resource: The destination_resource of this DescribeAvailableResourceRequest.  # noqa: E501
        :type: str
        """

        self._destination_resource = destination_resource

    @property
    def instance_charge_type(self):
        """Gets the instance_charge_type of this DescribeAvailableResourceRequest.  # noqa: E501


        :return: The instance_charge_type of this DescribeAvailableResourceRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_charge_type

    @instance_charge_type.setter
    def instance_charge_type(self, instance_charge_type):
        """Sets the instance_charge_type of this DescribeAvailableResourceRequest.


        :param instance_charge_type: The instance_charge_type of this DescribeAvailableResourceRequest.  # noqa: E501
        :type: str
        """

        self._instance_charge_type = instance_charge_type

    @property
    def instance_type(self):
        """Gets the instance_type of this DescribeAvailableResourceRequest.  # noqa: E501


        :return: The instance_type of this DescribeAvailableResourceRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type):
        """Sets the instance_type of this DescribeAvailableResourceRequest.


        :param instance_type: The instance_type of this DescribeAvailableResourceRequest.  # noqa: E501
        :type: str
        """

        self._instance_type = instance_type

    @property
    def instance_type_id(self):
        """Gets the instance_type_id of this DescribeAvailableResourceRequest.  # noqa: E501


        :return: The instance_type_id of this DescribeAvailableResourceRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_type_id

    @instance_type_id.setter
    def instance_type_id(self, instance_type_id):
        """Sets the instance_type_id of this DescribeAvailableResourceRequest.


        :param instance_type_id: The instance_type_id of this DescribeAvailableResourceRequest.  # noqa: E501
        :type: str
        """

        self._instance_type_id = instance_type_id

    @property
    def spot_strategy(self):
        """Gets the spot_strategy of this DescribeAvailableResourceRequest.  # noqa: E501


        :return: The spot_strategy of this DescribeAvailableResourceRequest.  # noqa: E501
        :rtype: str
        """
        return self._spot_strategy

    @spot_strategy.setter
    def spot_strategy(self, spot_strategy):
        """Sets the spot_strategy of this DescribeAvailableResourceRequest.


        :param spot_strategy: The spot_strategy of this DescribeAvailableResourceRequest.  # noqa: E501
        :type: str
        """

        self._spot_strategy = spot_strategy

    @property
    def zone_id(self):
        """Gets the zone_id of this DescribeAvailableResourceRequest.  # noqa: E501


        :return: The zone_id of this DescribeAvailableResourceRequest.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this DescribeAvailableResourceRequest.


        :param zone_id: The zone_id of this DescribeAvailableResourceRequest.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeAvailableResourceRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeAvailableResourceRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeAvailableResourceRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vpc

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class VpcForDescribeVpcsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'associate_cens': 'list[AssociateCenForDescribeVpcsOutput]',
        'cidr_block': 'str',
        'creation_time': 'str',
        'description': 'str',
        'dns_servers': 'list[str]',
        'nat_gateway_ids': 'list[str]',
        'network_acl_num': 'str',
        'project_name': 'str',
        'route_table_ids': 'list[str]',
        'security_group_ids': 'list[str]',
        'status': 'str',
        'subnet_ids': 'list[str]',
        'tags': 'list[TagForDescribeVpcsOutput]',
        'update_time': 'str',
        'vpc_id': 'str',
        'vpc_name': 'str'
    }

    attribute_map = {
        'account_id': 'AccountId',
        'associate_cens': 'AssociateCens',
        'cidr_block': 'CidrBlock',
        'creation_time': 'CreationTime',
        'description': 'Description',
        'dns_servers': 'DnsServers',
        'nat_gateway_ids': 'NatGatewayIds',
        'network_acl_num': 'NetworkAclNum',
        'project_name': 'ProjectName',
        'route_table_ids': 'RouteTableIds',
        'security_group_ids': 'SecurityGroupIds',
        'status': 'Status',
        'subnet_ids': 'SubnetIds',
        'tags': 'Tags',
        'update_time': 'UpdateTime',
        'vpc_id': 'VpcId',
        'vpc_name': 'VpcName'
    }

    def __init__(self, account_id=None, associate_cens=None, cidr_block=None, creation_time=None, description=None, dns_servers=None, nat_gateway_ids=None, network_acl_num=None, project_name=None, route_table_ids=None, security_group_ids=None, status=None, subnet_ids=None, tags=None, update_time=None, vpc_id=None, vpc_name=None, _configuration=None):  # noqa: E501
        """VpcForDescribeVpcsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._account_id = None
        self._associate_cens = None
        self._cidr_block = None
        self._creation_time = None
        self._description = None
        self._dns_servers = None
        self._nat_gateway_ids = None
        self._network_acl_num = None
        self._project_name = None
        self._route_table_ids = None
        self._security_group_ids = None
        self._status = None
        self._subnet_ids = None
        self._tags = None
        self._update_time = None
        self._vpc_id = None
        self._vpc_name = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if associate_cens is not None:
            self.associate_cens = associate_cens
        if cidr_block is not None:
            self.cidr_block = cidr_block
        if creation_time is not None:
            self.creation_time = creation_time
        if description is not None:
            self.description = description
        if dns_servers is not None:
            self.dns_servers = dns_servers
        if nat_gateway_ids is not None:
            self.nat_gateway_ids = nat_gateway_ids
        if network_acl_num is not None:
            self.network_acl_num = network_acl_num
        if project_name is not None:
            self.project_name = project_name
        if route_table_ids is not None:
            self.route_table_ids = route_table_ids
        if security_group_ids is not None:
            self.security_group_ids = security_group_ids
        if status is not None:
            self.status = status
        if subnet_ids is not None:
            self.subnet_ids = subnet_ids
        if tags is not None:
            self.tags = tags
        if update_time is not None:
            self.update_time = update_time
        if vpc_id is not None:
            self.vpc_id = vpc_id
        if vpc_name is not None:
            self.vpc_name = vpc_name

    @property
    def account_id(self):
        """Gets the account_id of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The account_id of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this VpcForDescribeVpcsOutput.


        :param account_id: The account_id of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def associate_cens(self):
        """Gets the associate_cens of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The associate_cens of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: list[AssociateCenForDescribeVpcsOutput]
        """
        return self._associate_cens

    @associate_cens.setter
    def associate_cens(self, associate_cens):
        """Sets the associate_cens of this VpcForDescribeVpcsOutput.


        :param associate_cens: The associate_cens of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: list[AssociateCenForDescribeVpcsOutput]
        """

        self._associate_cens = associate_cens

    @property
    def cidr_block(self):
        """Gets the cidr_block of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The cidr_block of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: str
        """
        return self._cidr_block

    @cidr_block.setter
    def cidr_block(self, cidr_block):
        """Sets the cidr_block of this VpcForDescribeVpcsOutput.


        :param cidr_block: The cidr_block of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: str
        """

        self._cidr_block = cidr_block

    @property
    def creation_time(self):
        """Gets the creation_time of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The creation_time of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: str
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this VpcForDescribeVpcsOutput.


        :param creation_time: The creation_time of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: str
        """

        self._creation_time = creation_time

    @property
    def description(self):
        """Gets the description of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The description of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this VpcForDescribeVpcsOutput.


        :param description: The description of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def dns_servers(self):
        """Gets the dns_servers of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The dns_servers of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._dns_servers

    @dns_servers.setter
    def dns_servers(self, dns_servers):
        """Sets the dns_servers of this VpcForDescribeVpcsOutput.


        :param dns_servers: The dns_servers of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: list[str]
        """

        self._dns_servers = dns_servers

    @property
    def nat_gateway_ids(self):
        """Gets the nat_gateway_ids of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The nat_gateway_ids of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._nat_gateway_ids

    @nat_gateway_ids.setter
    def nat_gateway_ids(self, nat_gateway_ids):
        """Sets the nat_gateway_ids of this VpcForDescribeVpcsOutput.


        :param nat_gateway_ids: The nat_gateway_ids of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: list[str]
        """

        self._nat_gateway_ids = nat_gateway_ids

    @property
    def network_acl_num(self):
        """Gets the network_acl_num of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The network_acl_num of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: str
        """
        return self._network_acl_num

    @network_acl_num.setter
    def network_acl_num(self, network_acl_num):
        """Sets the network_acl_num of this VpcForDescribeVpcsOutput.


        :param network_acl_num: The network_acl_num of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: str
        """

        self._network_acl_num = network_acl_num

    @property
    def project_name(self):
        """Gets the project_name of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The project_name of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this VpcForDescribeVpcsOutput.


        :param project_name: The project_name of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def route_table_ids(self):
        """Gets the route_table_ids of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The route_table_ids of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._route_table_ids

    @route_table_ids.setter
    def route_table_ids(self, route_table_ids):
        """Sets the route_table_ids of this VpcForDescribeVpcsOutput.


        :param route_table_ids: The route_table_ids of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: list[str]
        """

        self._route_table_ids = route_table_ids

    @property
    def security_group_ids(self):
        """Gets the security_group_ids of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The security_group_ids of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._security_group_ids

    @security_group_ids.setter
    def security_group_ids(self, security_group_ids):
        """Sets the security_group_ids of this VpcForDescribeVpcsOutput.


        :param security_group_ids: The security_group_ids of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: list[str]
        """

        self._security_group_ids = security_group_ids

    @property
    def status(self):
        """Gets the status of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The status of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this VpcForDescribeVpcsOutput.


        :param status: The status of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def subnet_ids(self):
        """Gets the subnet_ids of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The subnet_ids of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._subnet_ids

    @subnet_ids.setter
    def subnet_ids(self, subnet_ids):
        """Sets the subnet_ids of this VpcForDescribeVpcsOutput.


        :param subnet_ids: The subnet_ids of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: list[str]
        """

        self._subnet_ids = subnet_ids

    @property
    def tags(self):
        """Gets the tags of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The tags of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: list[TagForDescribeVpcsOutput]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this VpcForDescribeVpcsOutput.


        :param tags: The tags of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: list[TagForDescribeVpcsOutput]
        """

        self._tags = tags

    @property
    def update_time(self):
        """Gets the update_time of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The update_time of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this VpcForDescribeVpcsOutput.


        :param update_time: The update_time of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    @property
    def vpc_id(self):
        """Gets the vpc_id of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The vpc_id of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this VpcForDescribeVpcsOutput.


        :param vpc_id: The vpc_id of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    @property
    def vpc_name(self):
        """Gets the vpc_name of this VpcForDescribeVpcsOutput.  # noqa: E501


        :return: The vpc_name of this VpcForDescribeVpcsOutput.  # noqa: E501
        :rtype: str
        """
        return self._vpc_name

    @vpc_name.setter
    def vpc_name(self, vpc_name):
        """Sets the vpc_name of this VpcForDescribeVpcsOutput.


        :param vpc_name: The vpc_name of this VpcForDescribeVpcsOutput.  # noqa: E501
        :type: str
        """

        self._vpc_name = vpc_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VpcForDescribeVpcsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VpcForDescribeVpcsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VpcForDescribeVpcsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    auto_scaling

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ScalingActivityForDescribeScalingActivitiesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'activity_type': 'str',
        'actual_adjust_instance_number': 'int',
        'cooldown': 'int',
        'created_at': 'str',
        'current_instance_number': 'int',
        'expected_run_time': 'str',
        'max_instance_number': 'int',
        'min_instance_number': 'int',
        'related_instances': 'list[RelatedInstanceForDescribeScalingActivitiesOutput]',
        'result_msg': 'str',
        'scaling_activity_id': 'str',
        'scaling_group_id': 'str',
        'status_code': 'str',
        'stopped_at': 'str',
        'task_category': 'str'
    }

    attribute_map = {
        'activity_type': 'ActivityType',
        'actual_adjust_instance_number': 'ActualAdjustInstanceNumber',
        'cooldown': 'Cooldown',
        'created_at': 'CreatedAt',
        'current_instance_number': 'CurrentInstanceNumber',
        'expected_run_time': 'ExpectedRunTime',
        'max_instance_number': 'MaxInstanceNumber',
        'min_instance_number': 'MinInstanceNumber',
        'related_instances': 'RelatedInstances',
        'result_msg': 'ResultMsg',
        'scaling_activity_id': 'ScalingActivityId',
        'scaling_group_id': 'ScalingGroupId',
        'status_code': 'StatusCode',
        'stopped_at': 'StoppedAt',
        'task_category': 'TaskCategory'
    }

    def __init__(self, activity_type=None, actual_adjust_instance_number=None, cooldown=None, created_at=None, current_instance_number=None, expected_run_time=None, max_instance_number=None, min_instance_number=None, related_instances=None, result_msg=None, scaling_activity_id=None, scaling_group_id=None, status_code=None, stopped_at=None, task_category=None, _configuration=None):  # noqa: E501
        """ScalingActivityForDescribeScalingActivitiesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._activity_type = None
        self._actual_adjust_instance_number = None
        self._cooldown = None
        self._created_at = None
        self._current_instance_number = None
        self._expected_run_time = None
        self._max_instance_number = None
        self._min_instance_number = None
        self._related_instances = None
        self._result_msg = None
        self._scaling_activity_id = None
        self._scaling_group_id = None
        self._status_code = None
        self._stopped_at = None
        self._task_category = None
        self.discriminator = None

        if activity_type is not None:
            self.activity_type = activity_type
        if actual_adjust_instance_number is not None:
            self.actual_adjust_instance_number = actual_adjust_instance_number
        if cooldown is not None:
            self.cooldown = cooldown
        if created_at is not None:
            self.created_at = created_at
        if current_instance_number is not None:
            self.current_instance_number = current_instance_number
        if expected_run_time is not None:
            self.expected_run_time = expected_run_time
        if max_instance_number is not None:
            self.max_instance_number = max_instance_number
        if min_instance_number is not None:
            self.min_instance_number = min_instance_number
        if related_instances is not None:
            self.related_instances = related_instances
        if result_msg is not None:
            self.result_msg = result_msg
        if scaling_activity_id is not None:
            self.scaling_activity_id = scaling_activity_id
        if scaling_group_id is not None:
            self.scaling_group_id = scaling_group_id
        if status_code is not None:
            self.status_code = status_code
        if stopped_at is not None:
            self.stopped_at = stopped_at
        if task_category is not None:
            self.task_category = task_category

    @property
    def activity_type(self):
        """Gets the activity_type of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501


        :return: The activity_type of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :rtype: str
        """
        return self._activity_type

    @activity_type.setter
    def activity_type(self, activity_type):
        """Sets the activity_type of this ScalingActivityForDescribeScalingActivitiesOutput.


        :param activity_type: The activity_type of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :type: str
        """

        self._activity_type = activity_type

    @property
    def actual_adjust_instance_number(self):
        """Gets the actual_adjust_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501


        :return: The actual_adjust_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :rtype: int
        """
        return self._actual_adjust_instance_number

    @actual_adjust_instance_number.setter
    def actual_adjust_instance_number(self, actual_adjust_instance_number):
        """Sets the actual_adjust_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.


        :param actual_adjust_instance_number: The actual_adjust_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :type: int
        """

        self._actual_adjust_instance_number = actual_adjust_instance_number

    @property
    def cooldown(self):
        """Gets the cooldown of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501


        :return: The cooldown of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :rtype: int
        """
        return self._cooldown

    @cooldown.setter
    def cooldown(self, cooldown):
        """Sets the cooldown of this ScalingActivityForDescribeScalingActivitiesOutput.


        :param cooldown: The cooldown of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :type: int
        """

        self._cooldown = cooldown

    @property
    def created_at(self):
        """Gets the created_at of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501


        :return: The created_at of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ScalingActivityForDescribeScalingActivitiesOutput.


        :param created_at: The created_at of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def current_instance_number(self):
        """Gets the current_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501


        :return: The current_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :rtype: int
        """
        return self._current_instance_number

    @current_instance_number.setter
    def current_instance_number(self, current_instance_number):
        """Sets the current_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.


        :param current_instance_number: The current_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :type: int
        """

        self._current_instance_number = current_instance_number

    @property
    def expected_run_time(self):
        """Gets the expected_run_time of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501


        :return: The expected_run_time of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :rtype: str
        """
        return self._expected_run_time

    @expected_run_time.setter
    def expected_run_time(self, expected_run_time):
        """Sets the expected_run_time of this ScalingActivityForDescribeScalingActivitiesOutput.


        :param expected_run_time: The expected_run_time of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :type: str
        """

        self._expected_run_time = expected_run_time

    @property
    def max_instance_number(self):
        """Gets the max_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501


        :return: The max_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :rtype: int
        """
        return self._max_instance_number

    @max_instance_number.setter
    def max_instance_number(self, max_instance_number):
        """Sets the max_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.


        :param max_instance_number: The max_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :type: int
        """

        self._max_instance_number = max_instance_number

    @property
    def min_instance_number(self):
        """Gets the min_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501


        :return: The min_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :rtype: int
        """
        return self._min_instance_number

    @min_instance_number.setter
    def min_instance_number(self, min_instance_number):
        """Sets the min_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.


        :param min_instance_number: The min_instance_number of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :type: int
        """

        self._min_instance_number = min_instance_number

    @property
    def related_instances(self):
        """Gets the related_instances of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501


        :return: The related_instances of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :rtype: list[RelatedInstanceForDescribeScalingActivitiesOutput]
        """
        return self._related_instances

    @related_instances.setter
    def related_instances(self, related_instances):
        """Sets the related_instances of this ScalingActivityForDescribeScalingActivitiesOutput.


        :param related_instances: The related_instances of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :type: list[RelatedInstanceForDescribeScalingActivitiesOutput]
        """

        self._related_instances = related_instances

    @property
    def result_msg(self):
        """Gets the result_msg of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501


        :return: The result_msg of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :rtype: str
        """
        return self._result_msg

    @result_msg.setter
    def result_msg(self, result_msg):
        """Sets the result_msg of this ScalingActivityForDescribeScalingActivitiesOutput.


        :param result_msg: The result_msg of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :type: str
        """

        self._result_msg = result_msg

    @property
    def scaling_activity_id(self):
        """Gets the scaling_activity_id of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501


        :return: The scaling_activity_id of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :rtype: str
        """
        return self._scaling_activity_id

    @scaling_activity_id.setter
    def scaling_activity_id(self, scaling_activity_id):
        """Sets the scaling_activity_id of this ScalingActivityForDescribeScalingActivitiesOutput.


        :param scaling_activity_id: The scaling_activity_id of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :type: str
        """

        self._scaling_activity_id = scaling_activity_id

    @property
    def scaling_group_id(self):
        """Gets the scaling_group_id of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501


        :return: The scaling_group_id of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :rtype: str
        """
        return self._scaling_group_id

    @scaling_group_id.setter
    def scaling_group_id(self, scaling_group_id):
        """Sets the scaling_group_id of this ScalingActivityForDescribeScalingActivitiesOutput.


        :param scaling_group_id: The scaling_group_id of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :type: str
        """

        self._scaling_group_id = scaling_group_id

    @property
    def status_code(self):
        """Gets the status_code of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501


        :return: The status_code of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :rtype: str
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this ScalingActivityForDescribeScalingActivitiesOutput.


        :param status_code: The status_code of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :type: str
        """

        self._status_code = status_code

    @property
    def stopped_at(self):
        """Gets the stopped_at of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501


        :return: The stopped_at of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :rtype: str
        """
        return self._stopped_at

    @stopped_at.setter
    def stopped_at(self, stopped_at):
        """Sets the stopped_at of this ScalingActivityForDescribeScalingActivitiesOutput.


        :param stopped_at: The stopped_at of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :type: str
        """

        self._stopped_at = stopped_at

    @property
    def task_category(self):
        """Gets the task_category of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501


        :return: The task_category of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :rtype: str
        """
        return self._task_category

    @task_category.setter
    def task_category(self, task_category):
        """Sets the task_category of this ScalingActivityForDescribeScalingActivitiesOutput.


        :param task_category: The task_category of this ScalingActivityForDescribeScalingActivitiesOutput.  # noqa: E501
        :type: str
        """

        self._task_category = task_category

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScalingActivityForDescribeScalingActivitiesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScalingActivityForDescribeScalingActivitiesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ScalingActivityForDescribeScalingActivitiesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    rds_mysql_v2

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeDBInstancesRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'charge_type': 'str',
        'create_time_end': 'str',
        'create_time_start': 'str',
        'db_engine_version': 'str',
        'instance_id': 'str',
        'instance_name': 'str',
        'instance_status': 'str',
        'page_number': 'int',
        'page_size': 'int',
        'project_name': 'str',
        'zone_id': 'str'
    }

    attribute_map = {
        'charge_type': 'ChargeType',
        'create_time_end': 'CreateTimeEnd',
        'create_time_start': 'CreateTimeStart',
        'db_engine_version': 'DBEngineVersion',
        'instance_id': 'InstanceId',
        'instance_name': 'InstanceName',
        'instance_status': 'InstanceStatus',
        'page_number': 'PageNumber',
        'page_size': 'PageSize',
        'project_name': 'ProjectName',
        'zone_id': 'ZoneId'
    }

    def __init__(self, charge_type=None, create_time_end=None, create_time_start=None, db_engine_version=None, instance_id=None, instance_name=None, instance_status=None, page_number=None, page_size=None, project_name=None, zone_id=None, _configuration=None):  # noqa: E501
        """DescribeDBInstancesRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._charge_type = None
        self._create_time_end = None
        self._create_time_start = None
        self._db_engine_version = None
        self._instance_id = None
        self._instance_name = None
        self._instance_status = None
        self._page_number = None
        self._page_size = None
        self._project_name = None
        self._zone_id = None
        self.discriminator = None

        if charge_type is not None:
            self.charge_type = charge_type
        if create_time_end is not None:
            self.create_time_end = create_time_end
        if create_time_start is not None:
            self.create_time_start = create_time_start
        if db_engine_version is not None:
            self.db_engine_version = db_engine_version
        if instance_id is not None:
            self.instance_id = instance_id
        if instance_name is not None:
            self.instance_name = instance_name
        if instance_status is not None:
            self.instance_status = instance_status
        if page_number is not None:
            self.page_number = page_number
        if page_size is not None:
            self.page_size = page_size
        if project_name is not None:
            self.project_name = project_name
        if zone_id is not None:
            self.zone_id = zone_id

    @property
    def charge_type(self):
        """Gets the charge_type of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The charge_type of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._charge_type

    @charge_type.setter
    def charge_type(self, charge_type):
        """Sets the charge_type of this DescribeDBInstancesRequest.


        :param charge_type: The charge_type of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._charge_type = charge_type

    @property
    def create_time_end(self):
        """Gets the create_time_end of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The create_time_end of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._create_time_end

    @create_time_end.setter
    def create_time_end(self, create_time_end):
        """Sets the create_time_end of this DescribeDBInstancesRequest.


        :param create_time_end: The create_time_end of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._create_time_end = create_time_end

    @property
    def create_time_start(self):
        """Gets the create_time_start of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The create_time_start of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._create_time_start

    @create_time_start.setter
    def create_time_start(self, create_time_start):
        """Sets the create_time_start of this DescribeDBInstancesRequest.


        :param create_time_start: The create_time_start of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._create_time_start = create_time_start

    @property
    def db_engine_version(self):
        """Gets the db_engine_version of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The db_engine_version of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._db_engine_version

    @db_engine_version.setter
    def db_engine_version(self, db_engine_version):
        """Sets the db_engine_version of this DescribeDBInstancesRequest.


        :param db_engine_version: The db_engine_version of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._db_engine_version = db_engine_version

    @property
    def instance_id(self):
        """Gets the instance_id of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The instance_id of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this DescribeDBInstancesRequest.


        :param instance_id: The instance_id of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def instance_name(self):
        """Gets the instance_name of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The instance_name of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this DescribeDBInstancesRequest.


        :param instance_name: The instance_name of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._instance_name = instance_name

    @property
    def instance_status(self):
        """Gets the instance_status of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The instance_status of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_status

    @instance_status.setter
    def instance_status(self, instance_status):
        """Sets the instance_status of this DescribeDBInstancesRequest.


        :param instance_status: The instance_status of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._instance_status = instance_status

    @property
    def page_number(self):
        """Gets the page_number of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The page_number of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this DescribeDBInstancesRequest.


        :param page_number: The page_number of this DescribeDBInstancesRequest.  # noqa: E501
        :type: int
        """

        self._page_number = page_number

    @property
    def page_size(self):
        """Gets the page_size of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The page_size of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this DescribeDBInstancesRequest.


        :param page_size: The page_size of this DescribeDBInstancesRequest.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def project_name(self):
        """Gets the project_name of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The project_name of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this DescribeDBInstancesRequest.


        :param project_name: The project_name of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def zone_id(self):
        """Gets the zone_id of this DescribeDBInstancesRequest.  # noqa: E501


        :return: The zone_id of this DescribeDBInstancesRequest.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this DescribeDBInstancesRequest.


        :param zone_id: The zone_id of this DescribeDBInstancesRequest.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeDBInstancesRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeDBInstancesRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeDBInstancesRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ecs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ImageForDescribeImagesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'architecture': 'str',
        'created_at': 'str',
        'description': 'str',
        'image_id': 'str',
        'image_name': 'str',
        'image_owner_id': 'str',
        'is_support_cloud_init': 'bool',
        'os_name': 'str',
        'os_type': 'str',
        'platform': 'str',
        'platform_version': 'str',
        'project_name': 'str',
        'share_status': 'str',
        'size': 'int',
        'status': 'str',
        'updated_at': 'str',
        'virtual_size': 'str',
        'visibility': 'str'
    }

    attribute_map = {
        'architecture': 'Architecture',
        'created_at': 'CreatedAt',
        'description': 'Description',
        'image_id': 'ImageId',
        'image_name': 'ImageName',
        'image_owner_id': 'ImageOwnerId',
        'is_support_cloud_init': 'IsSupportCloudInit',
        'os_name': 'OsName',
        'os_type': 'OsType',
        'platform': 'Platform',
        'platform_version': 'PlatformVersion',
        'project_name': 'ProjectName',
        'share_status': 'ShareStatus',
        'size': 'Size',
        'status': 'Status',
        'updated_at': 'UpdatedAt',
        'virtual_size': 'VirtualSize',
        'visibility': 'Visibility'
    }

    def __init__(self, architecture=None, created_at=None, description=None, image_id=None, image_name=None, image_owner_id=None, is_support_cloud_init=None, os_name=None, os_type=None, platform=None, platform_version=None, project_name=None, share_status=None, size=None, status=None, updated_at=None, virtual_size=None, visibility=None, _configuration=None):  # noqa: E501
        """ImageForDescribeImagesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._architecture = None
        self._created_at = None
        self._description = None
        self._image_id = None
        self._image_name = None
        self._image_owner_id = None
        self._is_support_cloud_init = None
        self._os_name = None
        self._os_type = None
        self._platform = None
        self._platform_version = None
        self._project_name = None
        self._share_status = None
        self._size = None
        self._status = None
        self._updated_at = None
        self._virtual_size = None
        self._visibility = None
        self.discriminator = None

        if architecture is not None:
            self.architecture = architecture
        if created_at is not None:
            self.created_at = created_at
        if description is not None:
            self.description = description
        if image_id is not None:
            self.image_id = image_id
        if image_name is not None:
            self.image_name = image_name
        if image_owner_id is not None:
            self.image_owner_id = image_owner_id
        if is_support_cloud_init is not None:
            self.is_support_cloud_init = is_support_cloud_init
        if os_name is not None:
            self.os_name = os_name
        if os_type is not None:
            self.os_type = os_type
        if platform is not None:
            self.platform = platform
        if platform_version is not None:
            self.platform_version = platform_version
        if project_name is not None:
            self.project_name = project_name
        if share_status is not None:
            self.share_status = share_status
        if size is not None:
            self.size = size
        if status is not None:
            self.status = status
        if updated_at is not None:
            self.updated_at = updated_at
        if virtual_size is not None:
            self.virtual_size = virtual_size
        if visibility is not None:
            self.visibility = visibility

    @property
    def architecture(self):
        """Gets the architecture of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The architecture of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._architecture

    @architecture.setter
    def architecture(self, architecture):
        """Sets the architecture of this ImageForDescribeImagesOutput.


        :param architecture: The architecture of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._architecture = architecture

    @property
    def created_at(self):
        """Gets the created_at of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The created_at of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ImageForDescribeImagesOutput.


        :param created_at: The created_at of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def description(self):
        """Gets the description of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The description of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ImageForDescribeImagesOutput.


        :param description: The description of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def image_id(self):
        """Gets the image_id of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The image_id of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """Sets the image_id of this ImageForDescribeImagesOutput.


        :param image_id: The image_id of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._image_id = image_id

    @property
    def image_name(self):
        """Gets the image_name of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The image_name of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._image_name

    @image_name.setter
    def image_name(self, image_name):
        """Sets the image_name of this ImageForDescribeImagesOutput.


        :param image_name: The image_name of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._image_name = image_name

    @property
    def image_owner_id(self):
        """Gets the image_owner_id of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The image_owner_id of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._image_owner_id

    @image_owner_id.setter
    def image_owner_id(self, image_owner_id):
        """Sets the image_owner_id of this ImageForDescribeImagesOutput.


        :param image_owner_id: The image_owner_id of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._image_owner_id = image_owner_id

    @property
    def is_support_cloud_init(self):
        """Gets the is_support_cloud_init of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The is_support_cloud_init of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: bool
        """
        return self._is_support_cloud_init

    @is_support_cloud_init.setter
    def is_support_cloud_init(self, is_support_cloud_init):
        """Sets the is_support_cloud_init of this ImageForDescribeImagesOutput.


        :param is_support_cloud_init: The is_support_cloud_init of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: bool
        """

        self._is_support_cloud_init = is_support_cloud_init

    @property
    def os_name(self):
        """Gets the os_name of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The os_name of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._os_name

    @os_name.setter
    def os_name(self, os_name):
        """Sets the os_name of this ImageForDescribeImagesOutput.


        :param os_name: The os_name of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._os_name = os_name

    @property
    def os_type(self):
        """Gets the os_type of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The os_type of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._os_type

    @os_type.setter
    def os_type(self, os_type):
        """Sets the os_type of this ImageForDescribeImagesOutput.


        :param os_type: The os_type of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._os_type = os_type

    @property
    def platform(self):
        """Gets the platform of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The platform of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """Sets the platform of this ImageForDescribeImagesOutput.


        :param platform: The platform of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._platform = platform

    @property
    def platform_version(self):
        """Gets the platform_version of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The platform_version of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._platform_version

    @platform_version.setter
    def platform_version(self, platform_version):
        """Sets the platform_version of this ImageForDescribeImagesOutput.


        :param platform_version: The platform_version of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._platform_version = platform_version

    @property
    def project_name(self):
        """Gets the project_name of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The project_name of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this ImageForDescribeImagesOutput.


        :param project_name: The project_name of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def share_status(self):
        """Gets the share_status of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The share_status of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._share_status

    @share_status.setter
    def share_status(self, share_status):
        """Sets the share_status of this ImageForDescribeImagesOutput.


        :param share_status: The share_status of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._share_status = share_status

    @property
    def size(self):
        """Gets the size of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The size of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ImageForDescribeImagesOutput.


        :param size: The size of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def status(self):
        """Gets the status of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The status of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ImageForDescribeImagesOutput.


        :param status: The status of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def updated_at(self):
        """Gets the updated_at of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The updated_at of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ImageForDescribeImagesOutput.


        :param updated_at: The updated_at of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    @property
    def virtual_size(self):
        """Gets the virtual_size of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The virtual_size of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._virtual_size

    @virtual_size.setter
    def virtual_size(self, virtual_size):
        """Sets the virtual_size of this ImageForDescribeImagesOutput.


        :param virtual_size: The virtual_size of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._virtual_size = virtual_size

    @property
    def visibility(self):
        """Gets the visibility of this ImageForDescribeImagesOutput.  # noqa: E501


        :return: The visibility of this ImageForDescribeImagesOutput.  # noqa: E501
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this ImageForDescribeImagesOutput.


        :param visibility: The visibility of this ImageForDescribeImagesOutput.  # noqa: E501
        :type: str
        """

        self._visibility = visibility

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ImageForDescribeImagesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImageForDescribeImagesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImageForDescribeImagesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    rds_mysql

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class TemplateParamForCreateParameterTemplateInput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'default_value': 'str',
        'description': 'str',
        'expect_value': 'str',
        'name': 'str',
        'restart': 'bool',
        'running_value': 'str',
        'value_range': 'str'
    }

    attribute_map = {
        'default_value': 'DefaultValue',
        'description': 'Description',
        'expect_value': 'ExpectValue',
        'name': 'Name',
        'restart': 'Restart',
        'running_value': 'RunningValue',
        'value_range': 'ValueRange'
    }

    def __init__(self, default_value=None, description=None, expect_value=None, name=None, restart=None, running_value=None, value_range=None, _configuration=None):  # noqa: E501
        """TemplateParamForCreateParameterTemplateInput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._default_value = None
        self._description = None
        self._expect_value = None
        self._name = None
        self._restart = None
        self._running_value = None
        self._value_range = None
        self.discriminator = None

        if default_value is not None:
            self.default_value = default_value
        if description is not None:
            self.description = description
        if expect_value is not None:
            self.expect_value = expect_value
        if name is not None:
            self.name = name
        if restart is not None:
            self.restart = restart
        if running_value is not None:
            self.running_value = running_value
        if value_range is not None:
            self.value_range = value_range

    @property
    def default_value(self):
        """Gets the default_value of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501


        :return: The default_value of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501
        :rtype: str
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """Sets the default_value of this TemplateParamForCreateParameterTemplateInput.


        :param default_value: The default_value of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501
        :type: str
        """

        self._default_value = default_value

    @property
    def description(self):
        """Gets the description of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501


        :return: The description of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TemplateParamForCreateParameterTemplateInput.


        :param description: The description of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def expect_value(self):
        """Gets the expect_value of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501


        :return: The expect_value of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501
        :rtype: str
        """
        return self._expect_value

    @expect_value.setter
    def expect_value(self, expect_value):
        """Sets the expect_value of this TemplateParamForCreateParameterTemplateInput.


        :param expect_value: The expect_value of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501
        :type: str
        """

        self._expect_value = expect_value

    @property
    def name(self):
        """Gets the name of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501


        :return: The name of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TemplateParamForCreateParameterTemplateInput.


        :param name: The name of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def restart(self):
        """Gets the restart of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501


        :return: The restart of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501
        :rtype: bool
        """
        return self._restart

    @restart.setter
    def restart(self, restart):
        """Sets the restart of this TemplateParamForCreateParameterTemplateInput.


        :param restart: The restart of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501
        :type: bool
        """

        self._restart = restart

    @property
    def running_value(self):
        """Gets the running_value of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501


        :return: The running_value of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501
        :rtype: str
        """
        return self._running_value

    @running_value.setter
    def running_value(self, running_value):
        """Sets the running_value of this TemplateParamForCreateParameterTemplateInput.


        :param running_value: The running_value of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501
        :type: str
        """

        self._running_value = running_value

    @property
    def value_range(self):
        """Gets the value_range of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501


        :return: The value_range of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501
        :rtype: str
        """
        return self._value_range

    @value_range.setter
    def value_range(self, value_range):
        """Sets the value_range of this TemplateParamForCreateParameterTemplateInput.


        :param value_range: The value_range of this TemplateParamForCreateParameterTemplateInput.  # noqa: E501
        :type: str
        """

        self._value_range = value_range

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TemplateParamForCreateParameterTemplateInput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TemplateParamForCreateParameterTemplateInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TemplateParamForCreateParameterTemplateInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    clb

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeAclAttributesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'acl_entries': 'list[AclEntryForDescribeAclAttributesOutput]',
        'acl_id': 'str',
        'acl_name': 'str',
        'create_time': 'str',
        'description': 'str',
        'listeners': 'list[ListenerForDescribeAclAttributesOutput]',
        'project_name': 'str',
        'request_id': 'str',
        'status': 'str',
        'update_time': 'str'
    }

    attribute_map = {
        'acl_entries': 'AclEntries',
        'acl_id': 'AclId',
        'acl_name': 'AclName',
        'create_time': 'CreateTime',
        'description': 'Description',
        'listeners': 'Listeners',
        'project_name': 'ProjectName',
        'request_id': 'RequestId',
        'status': 'Status',
        'update_time': 'UpdateTime'
    }

    def __init__(self, acl_entries=None, acl_id=None, acl_name=None, create_time=None, description=None, listeners=None, project_name=None, request_id=None, status=None, update_time=None, _configuration=None):  # noqa: E501
        """DescribeAclAttributesResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._acl_entries = None
        self._acl_id = None
        self._acl_name = None
        self._create_time = None
        self._description = None
        self._listeners = None
        self._project_name = None
        self._request_id = None
        self._status = None
        self._update_time = None
        self.discriminator = None

        if acl_entries is not None:
            self.acl_entries = acl_entries
        if acl_id is not None:
            self.acl_id = acl_id
        if acl_name is not None:
            self.acl_name = acl_name
        if create_time is not None:
            self.create_time = create_time
        if description is not None:
            self.description = description
        if listeners is not None:
            self.listeners = listeners
        if project_name is not None:
            self.project_name = project_name
        if request_id is not None:
            self.request_id = request_id
        if status is not None:
            self.status = status
        if update_time is not None:
            self.update_time = update_time

    @property
    def acl_entries(self):
        """Gets the acl_entries of this DescribeAclAttributesResponse.  # noqa: E501


        :return: The acl_entries of this DescribeAclAttributesResponse.  # noqa: E501
        :rtype: list[AclEntryForDescribeAclAttributesOutput]
        """
        return self._acl_entries

    @acl_entries.setter
    def acl_entries(self, acl_entries):
        """Sets the acl_entries of this DescribeAclAttributesResponse.


        :param acl_entries: The acl_entries of this DescribeAclAttributesResponse.  # noqa: E501
        :type: list[AclEntryForDescribeAclAttributesOutput]
        """

        self._acl_entries = acl_entries

    @property
    def acl_id(self):
        """Gets the acl_id of this DescribeAclAttributesResponse.  # noqa: E501


        :return: The acl_id of this DescribeAclAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._acl_id

    @acl_id.setter
    def acl_id(self, acl_id):
        """Sets the acl_id of this DescribeAclAttributesResponse.


        :param acl_id: The acl_id of this DescribeAclAttributesResponse.  # noqa: E501
        :type: str
        """

        self._acl_id = acl_id

    @property
    def acl_name(self):
        """Gets the acl_name of this DescribeAclAttributesResponse.  # noqa: E501


        :return: The acl_name of this DescribeAclAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._acl_name

    @acl_name.setter
    def acl_name(self, acl_name):
        """Sets the acl_name of this DescribeAclAttributesResponse.


        :param acl_name: The acl_name of this DescribeAclAttributesResponse.  # noqa: E501
        :type: str
        """

        self._acl_name = acl_name

    @property
    def create_time(self):
        """Gets the create_time of this DescribeAclAttributesResponse.  # noqa: E501


        :return: The create_time of this DescribeAclAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this DescribeAclAttributesResponse.


        :param create_time: The create_time of this DescribeAclAttributesResponse.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def description(self):
        """Gets the description of this DescribeAclAttributesResponse.  # noqa: E501


        :return: The description of this DescribeAclAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DescribeAclAttributesResponse.


        :param description: The description of this DescribeAclAttributesResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def listeners(self):
        """Gets the listeners of this DescribeAclAttributesResponse.  # noqa: E501


        :return: The listeners of this DescribeAclAttributesResponse.  # noqa: E501
        :rtype: list[ListenerForDescribeAclAttributesOutput]
        """
        return self._listeners

    @listeners.setter
    def listeners(self, listeners):
        """Sets the listeners of this DescribeAclAttributesResponse.


        :param listeners: The listeners of this DescribeAclAttributesResponse.  # noqa: E501
        :type: list[ListenerForDescribeAclAttributesOutput]
        """

        self._listeners = listeners

    @property
    def project_name(self):
        """Gets the project_name of this DescribeAclAttributesResponse.  # noqa: E501


        :return: The project_name of this DescribeAclAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this DescribeAclAttributesResponse.


        :param project_name: The project_name of this DescribeAclAttributesResponse.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def request_id(self):
        """Gets the request_id of this DescribeAclAttributesResponse.  # noqa: E501


        :return: The request_id of this DescribeAclAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this DescribeAclAttributesResponse.


        :param request_id: The request_id of this DescribeAclAttributesResponse.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def status(self):
        """Gets the status of this DescribeAclAttributesResponse.  # noqa: E501


        :return: The status of this DescribeAclAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DescribeAclAttributesResponse.


        :param status: The status of this DescribeAclAttributesResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def update_time(self):
        """Gets the update_time of this DescribeAclAttributesResponse.  # noqa: E501


        :return: The update_time of this DescribeAclAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this DescribeAclAttributesResponse.


        :param update_time: The update_time of this DescribeAclAttributesResponse.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeAclAttributesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeAclAttributesResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeAclAttributesResponse):
            return True

        return self.to_dict() != other.to_dict()
